@@ -71,7 +71,7 @@ def executer(
         dir.mkdir(parents=True, exist_ok=True)
 
     with basic_pbar() as pbar:
-        task = pbar.add_task("f"Executing {file.name}", total=None)
+        task = pbar.add_task(f"Executing {file.name}", total=None)
         df = isql.run_sql_file(file)
 
         pbar.update(task, advance=50)
